/*
******************************************************************************

   BLT implementation for X target - header.

   Copyright (C) 2001	Christoph Egger	[Christoph_Egger@t-online.de]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <ggi/internal/blt.h>
#include <ggi/internal/blt_debug.h>
#include <ggi/display/x_galloc.h>


/*
 *	"exported" Function prototypes
 */
BltTie			BLT_X_tie;
BltSetImage		BLT_X_setimage;

BltCrossBlit		BLT_X_crossblit;
BltMultiCrossBlit       BLT_X_multicrossblit;
BltPolyCrossBlit        BLT_X_polycrossblit;

BltCrossVis2Vis         BLT_X_crossvis2vis;
BltCrossBlit2Vis        BLT_X_crossblit2vis;
BltBlit2Vis             BLT_X_blit2vis;



/* Structure holding private data.
 */
struct xblt_priv {
	void *dummy;
};

#define XBLT_PRIV(vis) ((struct xblt_priv *)(LIBGGI_BLTEXT(vis)->priv))


struct xblt_bob {
	struct GA_x_bob *bob;
};

#define GETBOB(blt)	((struct xblt_bob *)(blt->target))->bob



/* fast blitting functions
 * 
 * They do blitting with no stretching and ROP_NOP
 */

int fast_crossblit(ggiBlt_t src, ggiBlt_t dst);

int fast_crossvis2vis(ggi_visual_t src, int sx, int sy, int sw, int sh,
		      ggi_visual_t dst, int dx, int dy,
		      enum ggiGA_coordbase cm);

int fast_crossblit2vis(ggiBlt_t blt, ggi_visual_t vis,
		       int dx, int dy, enum ggiGA_coordbase cm);

int fast_blit2vis(ggiBlt_t blt, int dx, int dy);




/* fast ROP blitting functions
 * 
 * They do blitting with no stretching, but with ROP
 */

int rop_crossblit(ggiBlt_t src, ggiBlt_t dst,
		  enum ggiGA_rop rop);

int rop_multicrossblit(ggiBlt_source_list src, size_t nmemb, ggiBlt_t blt);

int rop_polycrossblit(ggiBlt_source_list src, size_t nmemb, ggiBlt_t blt);



int rop_crossvis2vis(ggi_visual_t src, int sx, int sy, int sw, int sh,
		     ggi_visual_t dst, int dx, int dy,
		     enum ggiGA_rop rop, enum ggiGA_coordbase cm);

int rop_crossblit2vis(ggiBlt_t blt, ggi_visual_t vis, int dx, int dy,
		      enum ggiGA_rop rop, enum ggiGA_coordbase cm);

int rop_blit2vis(ggiBlt_t blt, int dx, int dy, enum ggiGA_rop rop);




/* stretch and ROP blitting functions
 * 
 * They do blitting with stretching and with ROP
 */

int stretch_crossblit(ggiBlt_t src, ggiBlt_t dst,
		      int width, int height,
		      enum ggiGA_rop rop);

int stretch_multicrossblit(ggiBlt_source_list src, size_t nmemb,
			   ggiBlt_t blt, int width, int height);

int stretch_polycrossblit(ggiBlt_source_list src, size_t nmemb,
			  ggiBlt_t blt, int width, int height);



int stretch_crossvis2vis(ggi_visual_t src, int sx,int sy, int sw,int sh,
			 ggi_visual_t dst, int dx,int dy,
			 int width,int height, enum ggiGA_rop rop,
			 enum ggiGA_coordbase cm);

int stretch_crossblit2vis(ggiBlt_t blt, ggi_visual_t vis,
			  int dx, int dy, int width, int height,
			  enum ggiGA_rop rop, enum ggiGA_coordbase cm);

int stretch_blit2vis(ggiBlt_t blt, int dx, int dy, int width, int height,
		     enum ggiGA_rop rop);

